==> gallery-0.5.8.module.tgz: modules/gallery/module.inc.php <==
<?php

	/*
	*	Gekko - Open Source Web Development Framework
	*	------------------------------------------------------------------------
	*	Copyright (C) 2004-2005, J. Carlos Nieto <xiam@users.sourceforge.net>
	*	This program is Free Software.
	*
	*	@package	Gekko
	*	@license	http://www.gnu.org/copyleft/gpl.html GNU/GPL License 2.0
	*	@author		J. Carlos Nieto <xiam@users.sf.net>
	*	@version	CVS: $Id:$
	*	@link		http://gekkoware.sourceforge.net
	*/

	if (!defined("IN-GEKKO")) die("Get a life!");

	Class GekkoModule_Gallery {
		function create_menu() {
			return false;
		}
		function configure() {
			Conf::getKey("gallery", "items_per_page", 8, "i");
			Conf::getKey("gallery", "allow_user_comments", 1, "b");
			Conf::getKey("gallery", "items_per_admin_page", 24, "i");
			Conf::getKey("gallery", "thumbnail.longest_side", 140, "i");
		}
		function install() {

			$GLOBALS["db"]->query("
			CREATE TABLE ".db_table("gallery")." (
				ID SMALLINT (5) UNSIGNED NOT NULL AUTO_INCREMENT, PRIMARY KEY(ID),
				GalleryLink SMALLINT (5) UNSIGNED NOT NULL default '0',
				Title VARCHAR (255),
				Description TEXT,
				Status BIT default '1',
				Thumbnail VARCHAR (255),
				ThumbnailSize VARCHAR (32),
				AuthorID MEDIUMINT (8) UNSIGNED NOT NULL,
				CreationTime INT (11) UNSIGNED NOT NULL,
				LastUpdated INT (11) UNSIGNED NOT NULL,
				auth_Access VARCHAR (255)
			)
			", __FILE__, __LINE__, true);

			$GLOBALS["db"]->query("
			CREATE TABLE ".db_table("gallery_item")." (
				ID INT (11) UNSIGNED NOT NULL AUTO_INCREMENT, PRIMARY KEY (ID),
				GalleryLink SMALLINT (5) UNSIGNED NOT NULL,
				Title VARCHAR (255),
				Description TEXT,
				Thumbnail VARCHAR (255),
				ThumbnailSize VARCHAR (32),
				MediaURL VARCHAR (255),
				MediaSize VARCHAR (32),
				AuthorID MEDIUMINT (8) UNSIGNED NOT NULL,
				CreationTime INT (11) UNSIGNED NOT NULL,
				LastUpdated INT (11) UNSIGNED NOT NULL,
				AllowComments BIT default '1'
			)
			", __FILE__, __LINE__, true);

			modCore::registerModule($GLOBALS["cgdb"]["gallery"], "gallery", "*", $GLOBALS["cgdb"]["gallery"]);
		}
		function uninstall() {
			$GLOBALS["db"]->query("DROP TABLE IF EXISTS ".db_table("gallery"), __FILE__, __LINE__, true);
			$GLOBALS["db"]->query("DROP TABLE IF EXISTS ".db_table("gallery_item"), __FILE__, __LINE__, true);
		}
		function upgrade() {

		}
		function ext_uninstall($module) {

		}
	}

?>

==> gallery-0.5.10.module.tgz: modules/gallery/module.inc.php <==
<?php

	/*
	*	Gekko - Open Source Web Development Framework
	*	------------------------------------------------------------------------
	*	Copyright (C) 2004-2005, J. Carlos Nieto <xiam@users.sourceforge.net>
	*	This program is Free Software.
	*
	*	@package	Gekko
	*	@license	http://www.gnu.org/copyleft/gpl.html GNU/GPL License 2.0
	*	@author		J. Carlos Nieto <xiam@users.sf.net>
	*	@version	CVS: $Id:$
	*	@link		http://gekkoware.sourceforge.net
	*/

	if (!defined("IN-GEKKO")) die("Get a life!");

	Class GekkoModule_Gallery {
		function create_menu() {
			return false;
		}
		function configure() {
			Conf::getKey("gallery", "items_per_page", 8, "i");
			Conf::getKey("gallery", "allow_user_comments", 1, "b");
			Conf::getKey("gallery", "items_per_admin_page", 24, "i");
			Conf::getKey("gallery", "thumbnail.longest_side", 140, "i");
		}
		function install() {

			$GLOBALS["db"]->query("
			CREATE TABLE ".db_table("gallery")." (
				ID SMALLINT (5) UNSIGNED NOT NULL AUTO_INCREMENT, PRIMARY KEY(ID),
				GalleryLink SMALLINT (5) UNSIGNED NOT NULL default '0',
				Title VARCHAR (255),
				Description TEXT,
				Status ENUM('0','1') NOT NULL default '1',
				Thumbnail VARCHAR (255),
				ThumbnailSize VARCHAR (32),
				AuthorID MEDIUMINT (8) UNSIGNED NOT NULL,
				CreationTime INT (11) UNSIGNED NOT NULL,
				LastUpdated INT (11) UNSIGNED NOT NULL,
				auth_Access VARCHAR (255)
			)
			", __FILE__, __LINE__, true);

			$GLOBALS["db"]->query("
			CREATE TABLE ".db_table("gallery_item")." (
				ID INT (11) UNSIGNED NOT NULL AUTO_INCREMENT, PRIMARY KEY (ID),
				GalleryLink SMALLINT (5) UNSIGNED NOT NULL,
				Title VARCHAR (255),
				Description TEXT,
				Thumbnail VARCHAR (255),
				ThumbnailSize VARCHAR (32),
				MediaURL VARCHAR (255),
				MediaSize VARCHAR (32),
				AuthorID MEDIUMINT (8) UNSIGNED NOT NULL,
				CreationTime INT (11) UNSIGNED NOT NULL,
				LastUpdated INT (11) UNSIGNED NOT NULL,
				AllowComments ENUM('0','1') NOT NULL default '1'
			)
			", __FILE__, __LINE__, true);

			modCore::registerModule($GLOBALS["cgdb"]["gallery"], "gallery", "*", $GLOBALS["cgdb"]["gallery"]);
		}
		function uninstall() {
			$GLOBALS["db"]->query("DROP TABLE IF EXISTS ".db_table("gallery"), __FILE__, __LINE__, true);
			$GLOBALS["db"]->query("DROP TABLE IF EXISTS ".db_table("gallery_item"), __FILE__, __LINE__, true);
		}
		function upgrade($provided_v) {
			if (check_version("0.5.9", $provided_v) < 0) {
				$GLOBALS["db"]->query("ALTER TABLE ".db_table("gallery")."
				CHANGE COLUMN Status Status ENUM('0','1') NOT NULL default '1'",
				__FILE__, __LINE__);

				$GLOBALS["db"]->query("ALTER TABLE ".db_table("gallery_item")."
				CHANGE COLUMN AllowComments AllowComments ENUM('0','1') NOT NULL default '1'",
				__FILE__, __LINE__);
			}
		}
		function ext_uninstall($module) {

		}
	}

?>
